"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ElectricalSwitchFlipEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player flips a switch while Electrical is sabotaged.
 */
class ElectricalSwitchFlipEvent extends events_1.RevertableEvent {
    constructor(room, switchsystem, message, 
    /**
     * The player that flipped the switch. Only available if the client is
     * the host.
     */
    player, 
    /**
     * The ID of the switch that was flipped (from left-to-right, starting at 0).
     */
    switchId, 
    /**
     * Whether this switch is flipped.
     */
    flipped) {
        super();
        this.room = room;
        this.switchsystem = switchsystem;
        this.message = message;
        this.player = player;
        this.switchId = switchId;
        this.flipped = flipped;
        this.eventName = "electrical.switchflip";
        this._alteredSwitchId = switchId;
        this._alteredFlipped = flipped;
    }
    /**
     * The ID of the alternate switch to flip, if changed.
     */
    get alteredSwitchId() {
        return this._alteredSwitchId;
    }
    /**
     * The alternate value of the switch, if changed.
     */
    get alteredFlipped() {
        return this._alteredFlipped;
    }
    /**
     * Change the switch that was flipped.
     * @param switchId The ID of the switch to flip (from left-to-right, starting at 0).
     */
    setSwitchId(switchId) {
        this._alteredSwitchId = switchId;
    }
    /**
     * Set whether the switch is flipped.
     * @param flipped Whether the switch is flipped.
     */
    setFlipped(flipped) {
        this._alteredFlipped = flipped;
    }
}
exports.ElectricalSwitchFlipEvent = ElectricalSwitchFlipEvent;
ElectricalSwitchFlipEvent.eventName = "electrical.switchflip";
//# sourceMappingURL=SwitchFlip.js.map