import { RevertableEvent } from "@skeldjs/events";
import { ProtectPlayerMessage } from "@skeldjs/protocol";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { PlayerEvent } from "./PlayerEvent";
/**
 * Emitted when a player (who is a shapeshifter) shapeshifts back into their own
 * form after being shapeshifted as another play for some duration of time.
 *
 * Use {@link PlayerShapeshiftEvent} to listen for when a player actually shapeshifts
 * initially.
 */
export declare class PlayerRevertShapeshiftEvent<RoomType extends Hostable = Hostable> extends RevertableEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: ProtectPlayerMessage | undefined;
    /**
     * The player that the player shapeshifted from.
     */
    readonly target: PlayerData<RoomType>;
    /**
     * Whether or not to show an animation of the player shapeshifting.
     */
    readonly doAnimation: boolean;
    static eventName: "player.revertshapeshift";
    eventName: "player.revertshapeshift";
    private _alteredDoAnimation;
    constructor(room: RoomType, player: PlayerData<RoomType>, message: ProtectPlayerMessage | undefined, 
    /**
     * The player that the player shapeshifted from.
     */
    target: PlayerData<RoomType>, 
    /**
     * Whether or not to show an animation of the player shapeshifting.
     */
    doAnimation: boolean);
    /**
     * Whether or not to show an animation of the player shapeshifting instead, if altered.
     */
    get alteredDoAnimation(): boolean;
    /**
     * Change whether or not an animation will show the player shapeshifting.
     * @param doAnimation Whether or not to do show an animation of the player shape shifting.
     */
    setDoAnimation(doAnimation: boolean): void;
}
//# sourceMappingURL=RevertShapeshift.d.ts.map