"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerSyncSettingsEvent = void 0;
const events_1 = require("@skeldjs/events");
const protocol_1 = require("@skeldjs/protocol");
/**
 * Emitted when a player (i.e. the host of the room) sets the settings of the room.
 */
class PlayerSyncSettingsEvent extends events_1.BasicEvent {
    constructor(room, player, message, 
    /**
     * The settings that were set.
     */
    settings) {
        super();
        this.room = room;
        this.player = player;
        this.message = message;
        this.settings = settings;
        this.eventName = "player.syncsettings";
        this._alteredSettings = new protocol_1.GameSettings(settings);
        this._isDirty = false;
    }
    /**
     * The altered settings of the room that will be set, if changeed.
     */
    get alteredSettings() {
        return this._alteredSettings;
    }
    /**
     * Whether the {@link PlayerSyncSettingsEvent.alteredSettings} is different
     * from the {@link PlayerSyncSettingsEvent.settings}.
     */
    get isDirty() {
        return this._isDirty;
    }
    /**
     * Change the settings that were set.
     * @param settings The settings to set.
     */
    setSettings(settings) {
        this._alteredSettings.patch(settings);
        this._isDirty = true;
    }
}
exports.PlayerSyncSettingsEvent = PlayerSyncSettingsEvent;
PlayerSyncSettingsEvent.eventName = "player.syncsettings";
//# sourceMappingURL=SyncSettings.js.map